@@ -4,23 +4,25 @@ from django.conf import settings
 
 
 class AbstractCreateUpdateTime(models.Model):
-    created_time = models.DateTimeField(auto_now_add=True)
-    updated_time = models.DateTimeField(auto_now=True)
+    created_time = models.DateTimeField(auto_now_add=True, related_name="%(app_label)s_%(class)s_created_time")
+    updated_time = models.DateTimeField(auto_now=True, related_name="%(app_label)s_%(class)s_updated_time")
 
     class Meta:
         abstract = True
 
 
 class AbstractCreateUpdateUser(AbstractCreateUpdateTime):
-    created_by = models.ForeignKey(settings.AUTH_USER_MODEL, blank=True, null=True, on_delete=models.SET_NULL)
-    updated_by = models.ForeignKey(settings.AUTH_USER_MODEL, blank=True, null=True, on_delete=models.SET_NULL)
+    created_by = models.ForeignKey(settings.AUTH_USER_MODEL, blank=True, null=True, on_delete=models.SET_NULL,
+                                   related_name="%(app_label)s_%(class)s_created_by")
+    updated_by = models.ForeignKey(settings.AUTH_USER_MODEL, blank=True, null=True, on_delete=models.SET_NULL,
+                                   related_name="%(app_label)s_%(class)s_updated_by")
 
     class Meta:
         abstract = True
 
 
 class AbstractDeleteTime(AbstractCreateUpdateTime):
-    deleted_time = models.DateTimeField(blank=True, null=True)
+    deleted_time = models.DateTimeField(blank=True, null=True, related_name="%(app_label)s_%(class)s_deleted_time")
     is_deleted = models.BooleanField(default=False)
 
     def __init__(self, *args, **kwargs):
@@ -42,7 +44,8 @@ class AbstractDeleteTime(AbstractCreateUpdateTime):
 
 
 class AbstractDeleteUser(AbstractDeleteTime, AbstractCreateUpdateTime):
-    deleted_by = models.ForeignKey(settings.AUTH_USER_MODEL, blank=True, null=True, on_delete=models.SET_NULL)
+    deleted_by = models.ForeignKey(settings.AUTH_USER_MODEL, blank=True, null=True, on_delete=models.SET_NULL,
+                                   related_name="%(app_label)s_%(class)s_deleted_by")
 
     class Meta:
         abstract = True
